local E, L, V, P, G = unpack(ElvUI)
local MaUI = E:GetModule("MaUI")
local NP = E:GetModule("NamePlates")

--Cache global variables
--Lua functions
local _G = _G
local unpack = unpack
local format = format

--WoW API / Variables
local CreateFrame = CreateFrame
local IsAddOnLoaded = IsAddOnLoaded
local GetScreenWidth = GetScreenWidth
local SetCVar = SetCVar
local PlaySoundFile = PlaySoundFile
local ReloadUI = ReloadUI
local UIFrameFadeOut = UIFrameFadeOut
local ChatFrame_AddMessageGroup = ChatFrame_AddMessageGroup
local ChatFrame_RemoveAllMessageGroups = ChatFrame_RemoveAllMessageGroups
local ChatFrame_AddChannel = ChatFrame_AddChannel
local ChatFrame_RemoveChannel = ChatFrame_RemoveChannel
local ChangeChatColor = ChangeChatColor
local ToggleChatColorNamesByClassGroup = ToggleChatColorNamesByClassGroup
local FCF_ResetChatWindows = FCF_ResetChatWindows
local FCF_SetLocked = FCF_SetLocked
local FCF_DockFrame, FCF_UnDockFrame = FCF_DockFrame, FCF_UnDockFrame
local FCF_OpenNewWindow = FCF_OpenNewWindow
local FCF_SavePositionAndDimensions = FCF_SavePositionAndDimensions
local FCF_GetChatWindowInfo = FCF_GetChatWindowInfo
local FCF_SetWindowName = FCF_SetWindowName
local FCF_StopDragging = FCF_StopDragging
local FCF_SetChatWindowFontSize = FCF_SetChatWindowFontSize
local CLASS, CONTINUE, PREVIOUS = CLASS, CONTINUE, PREVIOUS
local NUM_CHAT_WINDOWS = NUM_CHAT_WINDOWS
local LOOT, GENERAL, TRADE = LOOT, GENERAL, TRADE
local GUILD_EVENT_LOG = GUILD_EVENT_LOG
local RAID_CLASS_COLORS = RAID_CLASS_COLORS
local CUSTOM_CLASS_COLORS = CUSTOM_CLASS_COLORS

local function MaUIGeneral()
	E.db["auras"]["font"] = "Expressway"
	E.db["auras"]["fontOutline"] = "OUTLINE"
	E.db["auras"]["fontSize"] = 12

	E.db["bags"]["bagSize"] = 32
	E.db["bags"]["bagWidth"] = 412
	E.db["bags"]["bankSize"] = 32
	E.db["bags"]["bankWidth"] = 412
	E.db["bags"]["clearSearchOnClose"] = true
	E.db["bags"]["countFont"] = "Expressway"
	E.db["bags"]["countFontOutline"] = "OUTLINE"
	E.db["bags"]["countFontSize"] = 12
	E.db["bags"]["currencyFormat"] = "ICON"
	E.db["bags"]["itemLevelFont"] = "Expressway"
	E.db["bags"]["itemLevelFontOutline"] = "OUTLINE"
	E.db["bags"]["itemLevelFontSize"] = 12
	E.db["bags"]["junkIcon"] = true
	E.db["bags"]["moneyFormat"] = "BLIZZARD"

	E.db["chat"]["font"] = "Expressway"
	E.db["chat"]["fontSize"] = 12
	E.db["chat"]["keywordSound"] = "Whisper Alert"
	E.db["chat"]["keywords"] = "ElvUI, %MYNAME%"
	E.db["chat"]["noAlertInCombat"] = true
	E.db["chat"]["numScrollMessages"] = 1
	E.db["chat"]["panelHeight"] = 150
	E.db["chat"]["tabFont"] = "Expressway"
	E.db["chat"]["tabFontSize"] = 16
	E.db["chat"]["tapFontSize"] = 12
	E.db["chat"]["timeStampFormat"] = "%H:%M "
	E.db["chat"]["useCustomTimeColor"] = false

	E.db["databars"]["artifact"]["font"] = "Expressway"
	E.db["databars"]["artifact"]["height"] = 5
	E.db["databars"]["artifact"]["hideInCombat"] = true
	E.db["databars"]["artifact"]["orientation"] = "HORIZONTAL"
	E.db["databars"]["artifact"]["width"] = 176
	E.db["databars"]["experience"]["font"] = "Expressway"
	E.db["databars"]["experience"]["height"] = 5
	E.db["databars"]["experience"]["hideInCombat"] = true
	E.db["databars"]["experience"]["orientation"] = "HORIZONTAL"
	E.db["databars"]["experience"]["width"] = 176
	E.db["databars"]["honor"]["font"] = "Expressway"
	E.db["databars"]["honor"]["height"] = 5
	E.db["databars"]["honor"]["hideInCombat"] = true
	E.db["databars"]["honor"]["orientation"] = "HORIZONTAL"
	E.db["databars"]["honor"]["textSize"] = 17
	E.db["databars"]["honor"]["width"] = 176
	E.db["databars"]["reputation"]["enable"] = true
	E.db["databars"]["reputation"]["font"] = "Expressway"
	E.db["databars"]["reputation"]["height"] = 5
	E.db["databars"]["reputation"]["hideInCombat"] = true
	E.db["databars"]["reputation"]["orientation"] = "HORIZONTAL"
	E.db["databars"]["reputation"]["width"] = 176
	E.db["datatexts"]["currencies"]["displayedCurrency"] = "ANCIENT_MANA"
	E.db["datatexts"]["font"] = "Expressway"
	E.db["datatexts"]["goldCoins"] = true
	E.db["datatexts"]["panels"]["LeftChatDataPanel"]["left"] = "Guild"
	E.db["datatexts"]["panels"]["LeftChatDataPanel"]["right"] = "Friends"
	E.db["datatexts"]["panels"]["LeftCoordDtPanel"] = "Ordensressourcen"
	E.db["datatexts"]["panels"]["LeftMiniPanel"] = "Prof"
	E.db["datatexts"]["panels"]["RightChatDataPanel"]["middle"] = "Menu"
	E.db["datatexts"]["panels"]["RightCoordDtPanel"] = "Verschleierter Argunit"
	E.db["datatexts"]["panels"]["RightMiniPanel"] = "Time"
	E.db["datatexts"]["time24"] = true

	E.db["general"]["autoRoll"] = true
	E.db["general"]["bordercolor"]["b"] = 0.14117647058823
	E.db["general"]["bordercolor"]["g"] = 0.14117647058823
	E.db["general"]["bordercolor"]["r"] = 0.14117647058823
	E.db["general"]["bottomPanel"] = false
	E.db["general"]["font"] = "Expressway"
	E.db["general"]["objectiveFrameHeight"] = 700
	E.db["general"]["talkingHeadFrameScale"] = 0.7
	E.db["general"]["totems"]["enable"] = false
	E.db["general"]["valuecolor"]["b"] = 0.45
	E.db["general"]["valuecolor"]["g"] = 0.83
	E.db["general"]["valuecolor"]["r"] = 0.67
	E.db["general"]["vendorGrays"] = true
	
	E.db["thinBorderColorSet"] = true
	
	E.db["tooltip"]["font"] = "Expressway"
	E.db["tooltip"]["fontSize"] = 12
	E.db["tooltip"]["headerFontSize"] = 16
	E.db["tooltip"]["healthBar"]["font"] = "Expressway"
	E.db["tooltip"]["healthBar"]["fontSize"] = 8
	E.db["tooltip"]["healthBar"]["height"] = 5
	E.db["tooltip"]["healthBar"]["statusPosition"] = "TOP"
	E.db["tooltip"]["healthBar"]["text"] = false
	E.db["tooltip"]["itemCount"] = "BOTH"
	
	E.db["movers"]["AlertFrameMover"] = "TOP,ElvUIParent,TOP,0,-20"
	E.db["movers"]["ArtifactBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-215"
	E.db["movers"]["ExperienceBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-209"
	E.db["movers"]["HonorBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-209"
	E.db["movers"]["LeftChatMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,4"
	E.db["movers"]["LootFrameMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,250,-82"
	E.db["movers"]["ObjectiveFrameMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-107,-259"
	E.db["movers"]["ReputationBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-4,-203"
	E.db["movers"]["RightChatMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-4,4"
	E.db["movers"]["TalkingHeadFrameMover"] = "TOP,ElvUIParent,TOP,0,-160"
	E.db["movers"]["TotemBarMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,417,4"
	E.db["movers"]["VehicleSeatMover"] = "TOPLEFT,ElvUIParent,TOPLEFT,87,-37"
	
	print ("|cff76FF03MaUI|r ... |cff1784d1General installation|r ... |cff76FF03OK|r")
	E:UpdateAll(true)
end

local function MaUIUnitframeTankDD()
	E.db["unitframe"]["colors"]["auraBarBuff"]["b"] = 0.73
	E.db["unitframe"]["colors"]["auraBarBuff"]["g"] = 0.55
	E.db["unitframe"]["colors"]["auraBarBuff"]["r"] = 0.96
	E.db["unitframe"]["colors"]["castClassColor"] = true
	E.db["unitframe"]["colors"]["castColor"]["b"] = 0
	E.db["unitframe"]["colors"]["castColor"]["g"] = 0.8156862745098
	E.db["unitframe"]["colors"]["castColor"]["r"] = 1
	E.db["unitframe"]["colors"]["customhealthbackdrop"] = true
	E.db["unitframe"]["colors"]["health_backdrop"]["b"] = 0.10196078431373
	E.db["unitframe"]["colors"]["health_backdrop"]["g"] = 0.10196078431373
	E.db["unitframe"]["colors"]["health_backdrop"]["r"] = 0.10196078431373
	E.db["unitframe"]["colors"]["healthclass"] = true
	
	E.db["unitframe"]["font"] = "Expressway"
	E.db["unitframe"]["fontOutline"] = "NONE"
	E.db["unitframe"]["fontSize"] = 12
	
	E.db["unitframe"]["smoothbars"] = true
	E.db["unitframe"]["statusbar"] = "MaUI 2"
	
	E.db["unitframe"]["units"]["arena"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["arena"]["buffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["arena"]["buffs"]["xOffset"] = -1
	E.db["unitframe"]["units"]["arena"]["buffs"]["yOffset"] = 0
	E.db["unitframe"]["units"]["arena"]["castbar"]["height"] = 10
	E.db["unitframe"]["units"]["arena"]["castbar"]["width"] = 184
	E.db["unitframe"]["units"]["arena"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 10,
			["text_format"] = "[health:current-percent] [afk]",
			["xOffset"] = 0,
			["yOffset"] = 15,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 14,
			["text_format"] = "[mRole] [namecolor][name:short]|cffFFFFFF | [level]",
			["xOffset"] = 0,
			["yOffset"] = 17,
		},
	}
	E.db["unitframe"]["units"]["arena"]["debuffs"]["attachTo"] = "BUFFS"
	E.db["unitframe"]["units"]["arena"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["arena"]["debuffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["arena"]["debuffs"]["xOffset"] = -3
	E.db["unitframe"]["units"]["arena"]["debuffs"]["yOffset"] = 0
	E.db["unitframe"]["units"]["arena"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["arena"]["height"] = 20
	E.db["unitframe"]["units"]["arena"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["arena"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["arena"]["spacing"] = 30
	E.db["unitframe"]["units"]["arena"]["width"] = 184
	
	E.db["unitframe"]["units"]["assist"]["height"] = 20
	E.db["unitframe"]["units"]["assist"]["targetsGroup"]["height"] = 20
	E.db["unitframe"]["units"]["assist"]["targetsGroup"]["width"] = 80
	E.db["unitframe"]["units"]["assist"]["width"] = 80
	
	E.db["unitframe"]["units"]["boss"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["boss"]["buffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["boss"]["buffs"]["xOffset"] = -1
	E.db["unitframe"]["units"]["boss"]["buffs"]["yOffset"] = 0
	E.db["unitframe"]["units"]["boss"]["castbar"]["height"] = 10
	E.db["unitframe"]["units"]["boss"]["castbar"]["width"] = 184
	E.db["unitframe"]["units"]["boss"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 10,
			["text_format"] = "[health:current-percent]",
			["xOffset"] = 0,
			["yOffset"] = 15,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 14,
			["text_format"] = "[mRole] [namecolor][name:short]|cffFFFFFF | [level]",
			["xOffset"] = 0,
			["yOffset"] = 17,
		},
	}
	E.db["unitframe"]["units"]["boss"]["debuffs"]["attachTo"] = "BUFFS"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["numrows"] = 1
	E.db["unitframe"]["units"]["boss"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["boss"]["debuffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["xOffset"] = -3
	E.db["unitframe"]["units"]["boss"]["debuffs"]["yOffset"] = 0
	E.db["unitframe"]["units"]["boss"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["boss"]["height"] = 20
	E.db["unitframe"]["units"]["boss"]["infoPanel"]["height"] = 17
	E.db["unitframe"]["units"]["boss"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["boss"]["portrait"]["camDistanceScale"] = 2
	E.db["unitframe"]["units"]["boss"]["portrait"]["width"] = 45
	E.db["unitframe"]["units"]["boss"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["boss"]["raidicon"]["attachTo"] = "RIGHT"
	E.db["unitframe"]["units"]["boss"]["raidicon"]["xOffset"] = -19
	E.db["unitframe"]["units"]["boss"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["boss"]["spacing"] = 30
	E.db["unitframe"]["units"]["boss"]["threatStyle"] = "GLOW"
	E.db["unitframe"]["units"]["boss"]["width"] = 184
	
	E.db["unitframe"]["units"]["focus"]["castbar"]["height"] = 7
	E.db["unitframe"]["units"]["focus"]["castbar"]["icon"] = false
	E.db["unitframe"]["units"]["focus"]["castbar"]["width"] = 130
	E.db["unitframe"]["units"]["focus"]["customTexts"] = {
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "CENTER",
			["size"] = 18,
			["text_format"] = "[namecolor][name:medium]",
			["xOffset"] = 0,
			["yOffset"] = 16,
		},
	}
	E.db["unitframe"]["units"]["focus"]["debuffs"]["anchorPoint"] = "BOTTOMLEFT"
	E.db["unitframe"]["units"]["focus"]["debuffs"]["yOffset"] = -12
	E.db["unitframe"]["units"]["focus"]["height"] = 20
	E.db["unitframe"]["units"]["focus"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["focus"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["focus"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["focus"]["width"] = 130
	
	E.db["unitframe"]["units"]["party"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 10,
			["text_format"] = "[mHealth]",
			["xOffset"] = 0,
			["yOffset"] = 15,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 14,
			["text_format"] = "[level] | [namecolor][name:short] [mRole]",
			["xOffset"] = 0,
			["yOffset"] = 17,
		},
	}
	E.db["unitframe"]["units"]["party"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["party"]["debuffs"]["priority"] = "Blacklist,Personal,nonPersonal"
	E.db["unitframe"]["units"]["party"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["party"]["debuffs"]["xOffset"] = 1
	E.db["unitframe"]["units"]["party"]["groupBy"] = "ROLE"
	E.db["unitframe"]["units"]["party"]["growthDirection"] = "DOWN_RIGHT"
	E.db["unitframe"]["units"]["party"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["height"] = 20
	E.db["unitframe"]["units"]["party"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["raidWideSorting"] = true
	E.db["unitframe"]["units"]["party"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["party"]["raidicon"]["xOffset"] = 19
	E.db["unitframe"]["units"]["party"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["enable"] = true
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["size"] = 18
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["xOffset"] = 40
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["yOffset"] = 1
	E.db["unitframe"]["units"]["party"]["readycheckIcon"]["position"] = "CENTER"
	E.db["unitframe"]["units"]["party"]["readycheckIcon"]["size"] = 20
	E.db["unitframe"]["units"]["party"]["readycheckIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["party"]["roleIcon"]["damager"] = false
	E.db["unitframe"]["units"]["party"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["party"]["roleIcon"]["size"] = 16
	E.db["unitframe"]["units"]["party"]["sortDir"] = "DESC"
	E.db["unitframe"]["units"]["party"]["verticalSpacing"] = 30
	
	E.db["unitframe"]["units"]["pet"]["castbar"]["enable"] = false
	E.db["unitframe"]["units"]["pet"]["castbar"]["width"] = 100
	E.db["unitframe"]["units"]["pet"]["customTexts"] = {
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "CENTER",
			["size"] = 18,
			["text_format"] = "[namecolor][name:short]",
			["xOffset"] = 0,
			["yOffset"] = 16,
		},
	}
	E.db["unitframe"]["units"]["pet"]["debuffs"]["anchorPoint"] = "BOTTOMLEFT"
	E.db["unitframe"]["units"]["pet"]["debuffs"]["yOffset"] = -1
	E.db["unitframe"]["units"]["pet"]["height"] = 20
	E.db["unitframe"]["units"]["pet"]["infoPanel"]["height"] = 14
	E.db["unitframe"]["units"]["pet"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["pet"]["portrait"]["camDistanceScale"] = 2
	E.db["unitframe"]["units"]["pet"]["width"] = 100
	
	E.db["unitframe"]["units"]["player"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["buffs"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["buffs"]["attachTo"] = "FRAME"
	E.db["unitframe"]["units"]["player"]["buffs"]["noDuration"] = false
	E.db["unitframe"]["units"]["player"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["player"]["castbar"]["height"] = 14
	E.db["unitframe"]["units"]["player"]["classbar"]["autoHide"] = true
	E.db["unitframe"]["units"]["player"]["classbar"]["detachFromFrame"] = true
	E.db["unitframe"]["units"]["player"]["classbar"]["detachedWidth"] = 270
	E.db["unitframe"]["units"]["player"]["classbar"]["fill"] = "spaced"
	E.db["unitframe"]["units"]["player"]["combatfade"] = true
	E.db["unitframe"]["units"]["player"]["customTexts"] = {
		["mKraft"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 10,
			["text_format"] = "[powercolor][power:percent]",
			["xOffset"] = 0,
			["yOffset"] = 33,
		},
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 14,
			["text_format"] = "[afk] [health:current-percent]",
			["xOffset"] = 0,
			["yOffset"] = 22,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 20,
			["text_format"] = "[mLevel] | [namecolor][name:medium]",
			["xOffset"] = 0,
			["yOffset"] = 24,
		},
		["mPvP"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "CENTER",
			["size"] = 16,
			["text_format"] = "|cFFB04F4F[pvptimer][mouseover]|r",
			["xOffset"] = 0,
			["yOffset"] = 0,
		},
	}
	E.db["unitframe"]["units"]["player"]["debuffs"]["attachTo"] = "HEALTH"
	E.db["unitframe"]["units"]["player"]["debuffs"]["perrow"] = 9
	E.db["unitframe"]["units"]["player"]["debuffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["player"]["debuffs"]["yOffset"] = 24
	E.db["unitframe"]["units"]["player"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["player"]["height"] = 25
	E.db["unitframe"]["units"]["player"]["name"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["player"]["name"]["text_format"] = "[mouseover][group]"
	E.db["unitframe"]["units"]["player"]["name"]["xOffset"] = 2
	E.db["unitframe"]["units"]["player"]["power"]["detachedWidth"] = 270
	E.db["unitframe"]["units"]["player"]["power"]["height"] = 7
	E.db["unitframe"]["units"]["player"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["player"]["power"]["xOffset"] = 0
	E.db["unitframe"]["units"]["player"]["pvp"]["text_format"] = ""
	E.db["unitframe"]["units"]["player"]["raidicon"]["attachTo"] = "RIGHT"
	E.db["unitframe"]["units"]["player"]["raidicon"]["xOffset"] = -2
	E.db["unitframe"]["units"]["player"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["player"]["restIcon"] = false
	
	E.db["unitframe"]["units"]["raid"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["raid"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 8,
			["text_format"] = "[mHealth]",
			["xOffset"] = 0,
			["yOffset"] = 13,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 12,
			["text_format"] = "[namecolor][name:short]",
			["xOffset"] = 0,
			["yOffset"] = 14,
		},
	}
	E.db["unitframe"]["units"]["raid"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["raid"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid"]["debuffs"]["xOffset"] = 1
	E.db["unitframe"]["units"]["raid"]["groupBy"] = "ROLE"
	E.db["unitframe"]["units"]["raid"]["groupsPerRowCol"] = 4
	E.db["unitframe"]["units"]["raid"]["growthDirection"] = "DOWN_RIGHT"
	E.db["unitframe"]["units"]["raid"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid"]["health"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["height"] = 20
	E.db["unitframe"]["units"]["raid"]["infoPanel"]["height"] = 15
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[mouseover][group]"
	E.db["unitframe"]["units"]["raid"]["numGroups"] = 8
	E.db["unitframe"]["units"]["raid"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["power"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid"]["power"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["raidWideSorting"] = true
	E.db["unitframe"]["units"]["raid"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["raidicon"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["size"] = 18
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["yOffset"] = 1
	E.db["unitframe"]["units"]["raid"]["readycheckIcon"]["position"] = "CENTER"
	E.db["unitframe"]["units"]["raid"]["readycheckIcon"]["size"] = 20
	E.db["unitframe"]["units"]["raid"]["readycheckIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["damager"] = false
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["sortDir"] = "DESC"
	E.db["unitframe"]["units"]["raid"]["verticalSpacing"] = 15
	E.db["unitframe"]["units"]["raid"]["visibility"] = "[@raid6,noexists] hide;show"
	
	E.db["unitframe"]["units"]["raid40"]["enable"] = false
	
	E.db["unitframe"]["units"]["tank"]["height"] = 20
	E.db["unitframe"]["units"]["tank"]["targetsGroup"]["height"] = 20
	E.db["unitframe"]["units"]["tank"]["targetsGroup"]["width"] = 80
	E.db["unitframe"]["units"]["tank"]["width"] = 80
	
	E.db["unitframe"]["units"]["target"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["buffs"]["attachTo"] = "HEALTH"
	E.db["unitframe"]["units"]["target"]["buffs"]["perrow"] = 9
	E.db["unitframe"]["units"]["target"]["buffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["target"]["buffs"]["yOffset"] = 24
	E.db["unitframe"]["units"]["target"]["customTexts"] = {
		["mKraft"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 10,
			["text_format"] = "[powercolor][power:percent]",
			["xOffset"] = 0,
			["yOffset"] = 33,
		},
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 14,
			["text_format"] = "[health:current-percent] [afk]",
			["xOffset"] = 0,
			["yOffset"] = 22,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 20,
			["text_format"] = "[namecolor][name:abbrev]|cffFFFFFF | [level][mClass]",
			["xOffset"] = 0,
			["yOffset"] = 24,
		},
	}
	E.db["unitframe"]["units"]["target"]["debuffs"]["attachTo"] = "HEALTH"
	E.db["unitframe"]["units"]["target"]["debuffs"]["perrow"] = 9
	E.db["unitframe"]["units"]["target"]["debuffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["target"]["debuffs"]["yOffset"] = 51
	E.db["unitframe"]["units"]["target"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["target"]["height"] = 25
	E.db["unitframe"]["units"]["target"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["power"]["detachedWidth"] = 270
	E.db["unitframe"]["units"]["target"]["power"]["height"] = 7
	E.db["unitframe"]["units"]["target"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["power"]["xOffset"] = 0
	E.db["unitframe"]["units"]["target"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["target"]["raidicon"]["xOffset"] = 2
	E.db["unitframe"]["units"]["target"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["target"]["smartAuraDisplay"] = "DISABLED"
	E.db["unitframe"]["units"]["target"]["smartAuraPosition"] = "DEBUFFS_ON_BUFFS"
	
	E.db["unitframe"]["units"]["targettarget"]["customTexts"] = {
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "CENTER",
			["size"] = 18,
			["text_format"] = "[namecolor][name:abbrev]",
			["xOffset"] = 0,
			["yOffset"] = 16,
		},
	}
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["anchorPoint"] = "BOTTOMLEFT"
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["priority"] = "Blacklist,Personal,nonPersonal"
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["yOffset"] = -1
	E.db["unitframe"]["units"]["targettarget"]["height"] = 20
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["targettarget"]["threatStyle"] = "GLOW"
	E.db["unitframe"]["units"]["targettarget"]["width"] = 100
	
	E.db["movers"]["ArenaHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-320,-417"
	E.db["movers"]["BossHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-320,-417"
	E.db["movers"]["ClassBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,-278,107"
	E.db["movers"]["ElvUF_AssistMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,87,960"
	E.db["movers"]["ElvUF_PartyMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,651"
	E.db["movers"]["ElvUF_PetMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,180"
	E.db["movers"]["ElvUF_PlayerCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,74"
	E.db["movers"]["ElvUF_PlayerMover"] = "BOTTOM,ElvUIParent,BOTTOM,-278,118"
	E.db["movers"]["ElvUF_Raid40Mover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,197"
	E.db["movers"]["ElvUF_RaidMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,883"
	E.db["movers"]["ElvUF_RaidpetMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,4,574"
	E.db["movers"]["ElvUF_TankMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,4,960"
	E.db["movers"]["ElvUF_TargetCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,90"
	E.db["movers"]["ElvUF_TargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,278,118"
	E.db["movers"]["ElvUF_TargetTargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,133"
	
	print ("|cff76FF03MaUI|r ... |cff1784d1Tank/ DD Profile installation|r ... |cff76FF03OK|r")
	E:UpdateAll(true)
end

local function MaUIUnitframeHeal()
	E.db["unitframe"]["colors"]["auraBarBuff"]["b"] = 0.73
	E.db["unitframe"]["colors"]["auraBarBuff"]["g"] = 0.55
	E.db["unitframe"]["colors"]["auraBarBuff"]["r"] = 0.96
	E.db["unitframe"]["colors"]["castClassColor"] = true
	E.db["unitframe"]["colors"]["castColor"]["b"] = 0
	E.db["unitframe"]["colors"]["castColor"]["g"] = 0.8156862745098
	E.db["unitframe"]["colors"]["castColor"]["r"] = 1
	E.db["unitframe"]["colors"]["customhealthbackdrop"] = true
	E.db["unitframe"]["colors"]["health_backdrop"]["b"] = 0.10196078431373
	E.db["unitframe"]["colors"]["health_backdrop"]["g"] = 0.10196078431373
	E.db["unitframe"]["colors"]["health_backdrop"]["r"] = 0.10196078431373
	E.db["unitframe"]["colors"]["healthclass"] = true
	
	E.db["unitframe"]["font"] = "Expressway"
	E.db["unitframe"]["fontOutline"] = "NONE"
	E.db["unitframe"]["fontSize"] = 12
	
	E.db["unitframe"]["smoothbars"] = true
	
	E.db["unitframe"]["statusbar"] = "MaUI 2"
	
	E.db["unitframe"]["units"]["arena"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["arena"]["buffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["arena"]["buffs"]["xOffset"] = -1
	E.db["unitframe"]["units"]["arena"]["buffs"]["yOffset"] = 0
	E.db["unitframe"]["units"]["arena"]["castbar"]["height"] = 10
	E.db["unitframe"]["units"]["arena"]["castbar"]["width"] = 184
	E.db["unitframe"]["units"]["arena"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 10,
			["text_format"] = "[health:current-percent] [afk]",
			["xOffset"] = 0,
			["yOffset"] = 15,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 14,
			["text_format"] = "[mRole] [namecolor][name:short]|cffFFFFFF | [level]",
			["xOffset"] = 0,
			["yOffset"] = 17,
		},
	}
	E.db["unitframe"]["units"]["arena"]["debuffs"]["attachTo"] = "BUFFS"
	E.db["unitframe"]["units"]["arena"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["arena"]["debuffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["arena"]["debuffs"]["xOffset"] = -3
	E.db["unitframe"]["units"]["arena"]["debuffs"]["yOffset"] = 0
	E.db["unitframe"]["units"]["arena"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["arena"]["height"] = 20
	E.db["unitframe"]["units"]["arena"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["arena"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["arena"]["spacing"] = 30
	E.db["unitframe"]["units"]["arena"]["width"] = 184
	
	E.db["unitframe"]["units"]["assist"]["height"] = 20
	E.db["unitframe"]["units"]["assist"]["targetsGroup"]["height"] = 20
	E.db["unitframe"]["units"]["assist"]["targetsGroup"]["width"] = 80
	E.db["unitframe"]["units"]["assist"]["width"] = 80
	
	E.db["unitframe"]["units"]["boss"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["boss"]["buffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["boss"]["buffs"]["xOffset"] = -1
	E.db["unitframe"]["units"]["boss"]["buffs"]["yOffset"] = 0
	E.db["unitframe"]["units"]["boss"]["castbar"]["height"] = 10
	E.db["unitframe"]["units"]["boss"]["castbar"]["width"] = 184
	E.db["unitframe"]["units"]["boss"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 10,
			["text_format"] = "[health:current-percent]",
			["xOffset"] = 0,
			["yOffset"] = 15,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 14,
			["text_format"] = "[mRole] [namecolor][name:short]|cffFFFFFF | [level]",
			["xOffset"] = 0,
			["yOffset"] = 17,
		},
	}
	E.db["unitframe"]["units"]["boss"]["debuffs"]["attachTo"] = "BUFFS"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["numrows"] = 1
	E.db["unitframe"]["units"]["boss"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["boss"]["debuffs"]["sortDirection"] = "ASCENDING"
	E.db["unitframe"]["units"]["boss"]["debuffs"]["xOffset"] = -3
	E.db["unitframe"]["units"]["boss"]["debuffs"]["yOffset"] = 0
	E.db["unitframe"]["units"]["boss"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["boss"]["height"] = 20
	E.db["unitframe"]["units"]["boss"]["infoPanel"]["height"] = 17
	E.db["unitframe"]["units"]["boss"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["boss"]["portrait"]["camDistanceScale"] = 2
	E.db["unitframe"]["units"]["boss"]["portrait"]["width"] = 45
	E.db["unitframe"]["units"]["boss"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["boss"]["raidicon"]["attachTo"] = "RIGHT"
	E.db["unitframe"]["units"]["boss"]["raidicon"]["xOffset"] = -19
	E.db["unitframe"]["units"]["boss"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["boss"]["spacing"] = 30
	E.db["unitframe"]["units"]["boss"]["threatStyle"] = "GLOW"
	E.db["unitframe"]["units"]["boss"]["width"] = 184
	
	E.db["unitframe"]["units"]["focus"]["castbar"]["height"] = 10
	E.db["unitframe"]["units"]["focus"]["castbar"]["icon"] = false
	E.db["unitframe"]["units"]["focus"]["castbar"]["width"] = 130
	E.db["unitframe"]["units"]["focus"]["customTexts"] = {
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "CENTER",
			["size"] = 18,
			["text_format"] = "[namecolor][name:medium]",
			["xOffset"] = 0,
			["yOffset"] = 16,
		},
	}
	E.db["unitframe"]["units"]["focus"]["debuffs"]["anchorPoint"] = "BOTTOMLEFT"
	E.db["unitframe"]["units"]["focus"]["debuffs"]["yOffset"] = -12
	E.db["unitframe"]["units"]["focus"]["height"] = 20
	E.db["unitframe"]["units"]["focus"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["focus"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["focus"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["focus"]["width"] = 130
	
	E.db["unitframe"]["units"]["party"]["buffs"]["clickThrough"] = true
	E.db["unitframe"]["units"]["party"]["buffs"]["perrow"] = 1
	E.db["unitframe"]["units"]["party"]["buffs"]["sizeOverride"] = 22
	E.db["unitframe"]["units"]["party"]["buffs"]["xOffset"] = 50
	E.db["unitframe"]["units"]["party"]["buffs"]["yOffset"] = -6
	E.db["unitframe"]["units"]["party"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 10,
			["text_format"] = "[mHealth]",
			["xOffset"] = 0,
			["yOffset"] = 15,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 14,
			["text_format"] = "[level] | [namecolor][name:short] [mRole]",
			["xOffset"] = 0,
			["yOffset"] = 17,
		},
	}
	E.db["unitframe"]["units"]["party"]["debuffs"]["anchorPoint"] = "BOTTOMRIGHT"
	E.db["unitframe"]["units"]["party"]["debuffs"]["perrow"] = 6
	E.db["unitframe"]["units"]["party"]["debuffs"]["priority"] = "Blacklist,Personal,nonPersonal"
	E.db["unitframe"]["units"]["party"]["debuffs"]["sizeOverride"] = 0
	E.db["unitframe"]["units"]["party"]["debuffs"]["yOffset"] = -2
	E.db["unitframe"]["units"]["party"]["groupBy"] = "ROLE"
	E.db["unitframe"]["units"]["party"]["growthDirection"] = "RIGHT_DOWN"
	E.db["unitframe"]["units"]["party"]["healPrediction"] = true
	E.db["unitframe"]["units"]["party"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["party"]["health"]["position"] = "BOTTOM"
	E.db["unitframe"]["units"]["party"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["height"] = 20
	E.db["unitframe"]["units"]["party"]["horizontalSpacing"] = 6
	E.db["unitframe"]["units"]["party"]["name"]["position"] = "TOP"
	E.db["unitframe"]["units"]["party"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["party"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["party"]["raidicon"]["xOffset"] = 19
	E.db["unitframe"]["units"]["party"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["enable"] = true
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["size"] = 18
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["xOffset"] = 40
	E.db["unitframe"]["units"]["party"]["rdebuffs"]["yOffset"] = 1
	E.db["unitframe"]["units"]["party"]["roleIcon"]["damager"] = false
	E.db["unitframe"]["units"]["party"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["party"]["roleIcon"]["size"] = 16
	E.db["unitframe"]["units"]["party"]["verticalSpacing"] = 30
	E.db["unitframe"]["units"]["party"]["width"] = 150
	
	E.db["unitframe"]["units"]["pet"]["castbar"]["enable"] = false
	E.db["unitframe"]["units"]["pet"]["castbar"]["width"] = 100
	E.db["unitframe"]["units"]["pet"]["customTexts"] = {
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "CENTER",
			["size"] = 18,
			["text_format"] = "[namecolor][name:short]",
			["xOffset"] = 0,
			["yOffset"] = 16,
		},
	}
	E.db["unitframe"]["units"]["pet"]["debuffs"]["anchorPoint"] = "BOTTOMLEFT"
	E.db["unitframe"]["units"]["pet"]["debuffs"]["yOffset"] = -1
	E.db["unitframe"]["units"]["pet"]["height"] = 20
	E.db["unitframe"]["units"]["pet"]["infoPanel"]["height"] = 14
	E.db["unitframe"]["units"]["pet"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["pet"]["portrait"]["camDistanceScale"] = 2
	E.db["unitframe"]["units"]["pet"]["width"] = 100
	
	E.db["unitframe"]["units"]["player"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["buffs"]["enable"] = false
	E.db["unitframe"]["units"]["player"]["buffs"]["attachTo"] = "FRAME"
	E.db["unitframe"]["units"]["player"]["buffs"]["noDuration"] = false
	E.db["unitframe"]["units"]["player"]["buffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["player"]["castbar"]["height"] = 14
	E.db["unitframe"]["units"]["player"]["classbar"]["autoHide"] = true
	E.db["unitframe"]["units"]["player"]["classbar"]["detachFromFrame"] = true
	E.db["unitframe"]["units"]["player"]["classbar"]["detachedWidth"] = 270
	E.db["unitframe"]["units"]["player"]["classbar"]["fill"] = "spaced"
	E.db["unitframe"]["units"]["player"]["combatfade"] = true
	E.db["unitframe"]["units"]["player"]["customTexts"] = {
		["mKraft"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 10,
			["text_format"] = "[powercolor][power:percent]",
			["xOffset"] = 0,
			["yOffset"] = 33,
		},
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 14,
			["text_format"] = "[afk] [health:current-percent]",
			["xOffset"] = 0,
			["yOffset"] = 22,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 20,
			["text_format"] = "[mLevel] | [namecolor][name:medium]",
			["xOffset"] = 0,
			["yOffset"] = 24,
		},
		["mPvP"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "CENTER",
			["size"] = 16,
			["text_format"] = "|cFFB04F4F[pvptimer][mouseover]|r",
			["xOffset"] = 0,
			["yOffset"] = 0,
		},
	}
	E.db["unitframe"]["units"]["player"]["debuffs"]["attachTo"] = "HEALTH"
	E.db["unitframe"]["units"]["player"]["debuffs"]["perrow"] = 9
	E.db["unitframe"]["units"]["player"]["debuffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["player"]["debuffs"]["yOffset"] = 24
	E.db["unitframe"]["units"]["player"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["player"]["height"] = 25
	E.db["unitframe"]["units"]["player"]["name"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["player"]["name"]["text_format"] = "[mouseover][group]"
	E.db["unitframe"]["units"]["player"]["name"]["xOffset"] = 2
	E.db["unitframe"]["units"]["player"]["power"]["detachedWidth"] = 270
	E.db["unitframe"]["units"]["player"]["power"]["height"] = 7
	E.db["unitframe"]["units"]["player"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["player"]["power"]["xOffset"] = 0
	E.db["unitframe"]["units"]["player"]["pvp"]["text_format"] = ""
	E.db["unitframe"]["units"]["player"]["raidicon"]["attachTo"] = "RIGHT"
	E.db["unitframe"]["units"]["player"]["raidicon"]["xOffset"] = -2
	E.db["unitframe"]["units"]["player"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["player"]["restIcon"] = false
	
	E.db["unitframe"]["units"]["raid"]["buffs"]["clickThrough"] = true
	E.db["unitframe"]["units"]["raid"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["raid"]["buffs"]["sizeOverride"] = 22
	E.db["unitframe"]["units"]["raid"]["buffs"]["xOffset"] = 50
	E.db["unitframe"]["units"]["raid"]["buffs"]["yOffset"] = -6
	E.db["unitframe"]["units"]["raid"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 8,
			["text_format"] = "[mHealth]",
			["xOffset"] = 0,
			["yOffset"] = 13,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 12,
			["text_format"] = "[namecolor][name:short]",
			["xOffset"] = 0,
			["yOffset"] = 14,
		},
	}
	E.db["unitframe"]["units"]["raid"]["debuffs"]["anchorPoint"] = "TOPRIGHT"
	E.db["unitframe"]["units"]["raid"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["raid"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid"]["debuffs"]["xOffset"] = 1
	E.db["unitframe"]["units"]["raid"]["debuffs"]["yOffset"] = -7
	E.db["unitframe"]["units"]["raid"]["groupBy"] = "ROLE"
	E.db["unitframe"]["units"]["raid"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["raid"]["healPrediction"] = true
	E.db["unitframe"]["units"]["raid"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["raid"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid"]["health"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["height"] = 20
	E.db["unitframe"]["units"]["raid"]["horizontalSpacing"] = 9
	E.db["unitframe"]["units"]["raid"]["infoPanel"]["height"] = 15
	E.db["unitframe"]["units"]["raid"]["name"]["text_format"] = "[mouseover][group]"
	E.db["unitframe"]["units"]["raid"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["power"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid"]["power"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["raidWideSorting"] = false
	E.db["unitframe"]["units"]["raid"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["raid"]["raidicon"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["enable"] = false
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["size"] = 18
	E.db["unitframe"]["units"]["raid"]["rdebuffs"]["yOffset"] = 1
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["damager"] = false
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["size"] = 16
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["roleIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid"]["sortDir"] = "DESC"
	E.db["unitframe"]["units"]["raid"]["verticalSpacing"] = 15
	
	E.db["unitframe"]["units"]["raid40"]["buffs"]["perrow"] = 4
	E.db["unitframe"]["units"]["raid40"]["customTexts"] = {
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 8,
			["text_format"] = "[mHealth]",
			["xOffset"] = 0,
			["yOffset"] = 13,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 12,
			["text_format"] = "[namecolor][name:short]",
			["xOffset"] = 0,
			["yOffset"] = 14,
		},
	}
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["perrow"] = 5
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["sizeOverride"] = 20
	E.db["unitframe"]["units"]["raid40"]["debuffs"]["xOffset"] = 1
	E.db["unitframe"]["units"]["raid40"]["groupBy"] = "ROLE"
	E.db["unitframe"]["units"]["raid40"]["groupsPerRowCol"] = 2
	E.db["unitframe"]["units"]["raid40"]["growthDirection"] = "RIGHT_UP"
	E.db["unitframe"]["units"]["raid40"]["healPrediction"] = true
	E.db["unitframe"]["units"]["raid40"]["health"]["frequentUpdates"] = true
	E.db["unitframe"]["units"]["raid40"]["health"]["position"] = "LEFT"
	E.db["unitframe"]["units"]["raid40"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["raid40"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid40"]["health"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["height"] = 20
	E.db["unitframe"]["units"]["raid40"]["infoPanel"]["height"] = 15
	E.db["unitframe"]["units"]["raid40"]["name"]["text_format"] = "[mouseover][group]"
	E.db["unitframe"]["units"]["raid40"]["orientation"] = "LEFT"
	E.db["unitframe"]["units"]["raid40"]["portrait"]["camDistanceScale"] = 2
	E.db["unitframe"]["units"]["raid40"]["power"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["power"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid40"]["power"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["raidWideSorting"] = false
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["xOffset"] = 2
	E.db["unitframe"]["units"]["raid40"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["font"] = "Expressway"
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["size"] = 18
	E.db["unitframe"]["units"]["raid40"]["rdebuffs"]["yOffset"] = 1
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["damager"] = false
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["enable"] = true
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["position"] = "RIGHT"
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["size"] = 16
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["xOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["roleIcon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["raid40"]["sortDir"] = "DESC"
	E.db["unitframe"]["units"]["raid40"]["verticalSpacing"] = 15
	
	E.db["unitframe"]["units"]["tank"]["height"] = 20
	E.db["unitframe"]["units"]["tank"]["targetsGroup"]["height"] = 20
	E.db["unitframe"]["units"]["tank"]["targetsGroup"]["width"] = 80
	E.db["unitframe"]["units"]["tank"]["width"] = 80
	
	E.db["unitframe"]["units"]["target"]["aurabar"]["enable"] = false
	E.db["unitframe"]["units"]["target"]["buffs"]["attachTo"] = "HEALTH"
	E.db["unitframe"]["units"]["target"]["buffs"]["perrow"] = 9
	E.db["unitframe"]["units"]["target"]["buffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["target"]["buffs"]["yOffset"] = 24
	E.db["unitframe"]["units"]["target"]["customTexts"] = {
		["mKraft"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 10,
			["text_format"] = "[powercolor][power:percent]",
			["xOffset"] = 0,
			["yOffset"] = 33,
		},
		["mLeben"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "LEFT",
			["size"] = 14,
			["text_format"] = "[health:current-percent] [afk]",
			["xOffset"] = 0,
			["yOffset"] = 22,
		},
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "RIGHT",
			["size"] = 20,
			["text_format"] = "[namecolor][name:abbrev]|cffFFFFFF | [level][mClass]",
			["xOffset"] = 0,
			["yOffset"] = 24,
		},
	}
	E.db["unitframe"]["units"]["target"]["debuffs"]["attachTo"] = "HEALTH"
	E.db["unitframe"]["units"]["target"]["debuffs"]["perrow"] = 9
	E.db["unitframe"]["units"]["target"]["debuffs"]["sizeOverride"] = 30
	E.db["unitframe"]["units"]["target"]["debuffs"]["yOffset"] = 51
	E.db["unitframe"]["units"]["target"]["health"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["health"]["xOffset"] = 2
	E.db["unitframe"]["units"]["target"]["height"] = 25
	E.db["unitframe"]["units"]["target"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["power"]["detachedWidth"] = 270
	E.db["unitframe"]["units"]["target"]["power"]["height"] = 7
	E.db["unitframe"]["units"]["target"]["power"]["text_format"] = ""
	E.db["unitframe"]["units"]["target"]["power"]["xOffset"] = 0
	E.db["unitframe"]["units"]["target"]["raidicon"]["attachTo"] = "LEFT"
	E.db["unitframe"]["units"]["target"]["raidicon"]["xOffset"] = 2
	E.db["unitframe"]["units"]["target"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["target"]["smartAuraDisplay"] = "DISABLED"
	E.db["unitframe"]["units"]["target"]["smartAuraPosition"] = "DEBUFFS_ON_BUFFS"
	
	E.db["unitframe"]["units"]["targettarget"]["customTexts"] = {
		["mName"] = {
			["attachTextTo"] = "Health",
			["font"] = "Expressway",
			["fontOutline"] = "NONE",
			["justifyH"] = "CENTER",
			["size"] = 18,
			["text_format"] = "[namecolor][name:abbrev]",
			["xOffset"] = 0,
			["yOffset"] = 16,
		},
	}
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["anchorPoint"] = "BOTTOMLEFT"
	E.db["unitframe"]["units"]["targettarget"]["debuffs"]["yOffset"] = -1
	E.db["unitframe"]["units"]["targettarget"]["height"] = 20
	E.db["unitframe"]["units"]["targettarget"]["name"]["text_format"] = ""
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["attachTo"] = "CENTER"
	E.db["unitframe"]["units"]["targettarget"]["raidicon"]["yOffset"] = 0
	E.db["unitframe"]["units"]["targettarget"]["threatStyle"] = "GLOW"
	E.db["unitframe"]["units"]["targettarget"]["width"] = 100
	
	E.db["movers"]["ArenaHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-320,-417"
	E.db["movers"]["BossHeaderMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-320,-417"
	E.db["movers"]["ClassBarMover"] = "BOTTOM,ElvUIParent,BOTTOM,-278,107"
	E.db["movers"]["ElvUF_AssistMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,1170,420"
	E.db["movers"]["ElvUF_FocusMover"] = "BOTTOMRIGHT,ElvUIParent,BOTTOMRIGHT,-410,227"
	E.db["movers"]["ElvUF_PartyMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,573,260"
	E.db["movers"]["ElvUF_PetMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,180"
	E.db["movers"]["ElvUF_PlayerCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,74"
	E.db["movers"]["ElvUF_PlayerMover"] = "BOTTOM,ElvUIParent,BOTTOM,-278,118"
	E.db["movers"]["ElvUF_Raid40Mover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,547,216"
	E.db["movers"]["ElvUF_RaidMover"] = "BOTTOMLEFT,ElvUIParent,BOTTOMLEFT,754,216"
	E.db["movers"]["ElvUF_TankMover"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,630,420"
	E.db["movers"]["ElvUF_TargetCastbarMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,90"
	E.db["movers"]["ElvUF_TargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,278,118"
	E.db["movers"]["ElvUF_TargetTargetMover"] = "BOTTOM,ElvUIParent,BOTTOM,0,133"
	
	print ("|cff76FF03MaUI|r ... |cff1784d1Heal Profile installation|r ... |cff76FF03OK|r")
	E:UpdateAll(true)
end

local function CreateStyleFilter(name)
	local filter = {} --Create filter table
	NP:StyleFilterInitializeFilter(filter) --Initialize new filter with default options
	E.global.nameplate.filters[name] = filter --Add new filter to database
	
	--Add the "Enable" option to current profile
	if not E.db.nameplates then E.db.nameplates = {} end
	if not E.db.nameplates.filters then E.db.nameplates.filters = {} end
	if not E.db.nameplates.filters[name] then E.db.nameplates.filters[name] = {} end
	if not E.db.nameplates.filters[name].triggers then E.db.nameplates.filters[name].triggers = {} end
	E.db["nameplates"]["filters"][name]["triggers"]["enable"] = true
end

local function MaUINameplates()
	--Create new filter with name "MyStyleFilterName"
	CreateStyleFilter("Quest")
	CreateStyleFilter("Rar")
	
	--Modify some options
	E.global["nameplate"]["filters"]["Boss"]["actions"]["flash"]["color"]["a"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["flash"]["color"]["b"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["flash"]["color"]["g"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["flash"]["color"]["r"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["flash"]["enable"] = false
	E.global["nameplate"]["filters"]["Boss"]["actions"]["flash"]["speed"] = 4
	E.global["nameplate"]["filters"]["Boss"]["actions"]["hide"] = false
	E.global["nameplate"]["filters"]["Boss"]["actions"]["scale"] = 1.2
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["name"] = true
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["borderColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["borderColor"]["b"] = 0.14117647058823
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["borderColor"]["g"] = 0.11764705882353
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["borderColor"]["r"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["healthColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["healthColor"]["b"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["healthColor"]["g"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["healthColor"]["r"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["health"] = false
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["border"] = true
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["nameColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["nameColor"]["b"] = 0.14117647058823
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["nameColor"]["g"] = 0.11764705882353
	E.global["nameplate"]["filters"]["Boss"]["actions"]["color"]["nameColor"]["r"] = 1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["nameOnly"] = false
	E.global["nameplate"]["filters"]["Boss"]["actions"]["alpha"] = -1
	E.global["nameplate"]["filters"]["Boss"]["actions"]["texture"]["enable"] = true
	E.global["nameplate"]["filters"]["Boss"]["actions"]["texture"]["texture"] = "MaUI 2"
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["debuffs"]["minTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["debuffs"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["debuffs"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["debuffs"]["maxTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["notTarget"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceType"]["party"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceType"]["scenario"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceType"]["pvp"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceType"]["raid"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceType"]["arena"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceType"]["none"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["inCombatUnit"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["healthThreshold"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["dungeon"]["normal"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["dungeon"]["mythic+"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["dungeon"]["heroic"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["dungeon"]["timewalking"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["dungeon"]["mythic"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["normal"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["legacy25normal"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["heroic"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["legacy10normal"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["legacy10heroic"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["legacy25heroic"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["lfr"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["timewalking"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["instanceDifficulty"]["raid"]["mythic"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["casting"]["interruptible"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["powerThreshold"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["cooldowns"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["maxlevel"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["overPowerThreshold"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["priority"] = 1
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["healthUsePlayer"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier1enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier5"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier5"]["column"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier2enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier1"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier1"]["column"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier4"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier4"]["column"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["type"] = "normal"
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier2"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier2"]["column"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier4enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier3"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier3"]["column"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier5enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier7"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier7"]["column"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier7enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["requireAll"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier6enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier3enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier6"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["talent"]["tier6"]["column"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["role"]["tank"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["role"]["damager"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["role"]["healer"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["classification"]["elite"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["classification"]["minus"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["classification"]["trivial"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["classification"]["normal"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["classification"]["worldboss"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["classification"]["rareelite"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["classification"]["rare"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["overHealthThreshold"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["nameplateType"]["healer"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["nameplateType"]["enemyPlayer"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["nameplateType"]["friendlyPlayer"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["nameplateType"]["neutral"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["nameplateType"]["friendlyNPC"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["minlevel"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["outOfCombat"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["powerUsePlayer"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["outOfCombatUnit"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["underHealthThreshold"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["questBoss"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["underPowerThreshold"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["enabled"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["reputation"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["friendly"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["revered"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["honored"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["hostile"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["unfriendly"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["exalted"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["neutral"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["reactionType"]["hated"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["buffs"]["minTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["buffs"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["buffs"]["missing"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["buffs"]["maxTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["isTarget"] = false
	E.global["nameplate"]["filters"]["Boss"]["triggers"]["inCombat"] = false
	
	E.global["nameplate"]["filters"]["Quest"]["actions"]["flash"]["speed"] = 4
	E.global["nameplate"]["filters"]["Quest"]["actions"]["flash"]["color"]["a"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["flash"]["color"]["r"] = 0.1843137254902
	E.global["nameplate"]["filters"]["Quest"]["actions"]["flash"]["color"]["g"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["flash"]["color"]["b"] = 0
	E.global["nameplate"]["filters"]["Quest"]["actions"]["flash"]["enable"] = false
	E.global["nameplate"]["filters"]["Quest"]["actions"]["usePortrait"] = false
	E.global["nameplate"]["filters"]["Quest"]["actions"]["hide"] = false
	E.global["nameplate"]["filters"]["Quest"]["actions"]["scale"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["name"] = true
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["borderColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["borderColor"]["b"] = 0.14117647058823
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["borderColor"]["g"] = 0.74901960784314
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["borderColor"]["r"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["healthColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["healthColor"]["b"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["healthColor"]["g"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["healthColor"]["r"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["health"] = false
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["border"] = true
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["nameColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["nameColor"]["b"] = 0.14117647058823
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["nameColor"]["g"] = 0.74901960784314
	E.global["nameplate"]["filters"]["Quest"]["actions"]["color"]["nameColor"]["r"] = 1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["nameOnly"] = false
	E.global["nameplate"]["filters"]["Quest"]["actions"]["alpha"] = -1
	E.global["nameplate"]["filters"]["Quest"]["actions"]["texture"]["enable"] = false
	E.global["nameplate"]["filters"]["Quest"]["actions"]["texture"]["texture"] = "ElvUI Norm"
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["debuffs"]["minTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["debuffs"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["debuffs"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["debuffs"]["maxTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceType"]["party"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceType"]["scenario"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceType"]["pvp"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceType"]["raid"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceType"]["arena"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceType"]["none"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["inCombatUnit"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["powerThreshold"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["maxlevel"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["level"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["overHealthThreshold"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["nameplateType"]["neutral"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["nameplateType"]["enemyNPC"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["nameplateType"]["healer"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["nameplateType"]["enable"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["nameplateType"]["enemyPlayer"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["nameplateType"]["friendlyPlayer"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["nameplateType"]["friendlyNPC"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["underHealthThreshold"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["reputation"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["friendly"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["revered"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["honored"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["hostile"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["unfriendly"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["exalted"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["neutral"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["reactionType"]["hated"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["buffs"]["minTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["buffs"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["buffs"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["buffs"]["maxTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["inCombat"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["healthThreshold"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["curlevel"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["isTarget"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["priority"] = 1
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["healthUsePlayer"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["classification"]["elite"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["classification"]["minus"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["classification"]["trivial"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["classification"]["normal"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["classification"]["worldboss"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["classification"]["rareelite"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["classification"]["rare"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["underPowerThreshold"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier1enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier5"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier5"]["column"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier2enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier1"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier1"]["column"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier4"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier4"]["column"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["type"] = "normal"
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier2"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier2"]["column"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier4enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier3"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier3"]["column"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier5enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier7"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier7"]["column"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier7enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["requireAll"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier6enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier3enabled"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier6"]["missing"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["talent"]["tier6"]["column"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["minlevel"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["outOfCombatUnit"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["powerUsePlayer"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["outOfCombat"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["role"]["tank"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["role"]["damager"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["role"]["healer"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["questBoss"] = true
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["overPowerThreshold"] = 0
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["cooldowns"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["casting"]["interruptible"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["dungeon"]["normal"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["dungeon"]["mythic+"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["dungeon"]["heroic"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["dungeon"]["timewalking"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["dungeon"]["mythic"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["normal"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["legacy25normal"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["heroic"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["legacy10normal"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["legacy10heroic"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["legacy25heroic"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["lfr"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["timewalking"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["instanceDifficulty"]["raid"]["mythic"] = false
	E.global["nameplate"]["filters"]["Quest"]["triggers"]["notTarget"] = false
	E.global["nameplate"]["filters"]["Rar"]["actions"]["flash"]["speed"] = 4
	E.global["nameplate"]["filters"]["Rar"]["actions"]["flash"]["color"]["a"] = 1
	E.global["nameplate"]["filters"]["Rar"]["actions"]["flash"]["color"]["r"] = 0.63921568627451
	E.global["nameplate"]["filters"]["Rar"]["actions"]["flash"]["color"]["g"] = 0.18823529411765
	E.global["nameplate"]["filters"]["Rar"]["actions"]["flash"]["color"]["b"] = 0.78823529411765
	E.global["nameplate"]["filters"]["Rar"]["actions"]["flash"]["enable"] = false
	E.global["nameplate"]["filters"]["Rar"]["actions"]["usePortrait"] = true
	E.global["nameplate"]["filters"]["Rar"]["actions"]["hide"] = false
	E.global["nameplate"]["filters"]["Rar"]["actions"]["scale"] = 1
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["name"] = true
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["borderColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["borderColor"]["r"] = 0.63921568627451
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["borderColor"]["g"] = 0.18823529411765
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["borderColor"]["b"] = 0.78823529411765
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["healthColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["healthColor"]["b"] = 0.85098039215686
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["healthColor"]["g"] = 0.54117647058824
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["healthColor"]["r"] = 0.4078431372549
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["nameColor"]["a"] = 1
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["nameColor"]["b"] = 0.78823529411765
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["nameColor"]["g"] = 0.18823529411765
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["nameColor"]["r"] = 0.63921568627451
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["border"] = true
	E.global["nameplate"]["filters"]["Rar"]["actions"]["color"]["health"] = false
	E.global["nameplate"]["filters"]["Rar"]["actions"]["nameOnly"] = false
	E.global["nameplate"]["filters"]["Rar"]["actions"]["alpha"] = -1
	E.global["nameplate"]["filters"]["Rar"]["actions"]["texture"]["enable"] = false
	E.global["nameplate"]["filters"]["Rar"]["actions"]["texture"]["texture"] = "ElvUI Norm"
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["debuffs"]["minTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["debuffs"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["debuffs"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["debuffs"]["maxTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceType"]["party"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceType"]["scenario"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceType"]["pvp"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceType"]["raid"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceType"]["arena"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceType"]["none"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["inCombatUnit"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["powerThreshold"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["maxlevel"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["level"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["overHealthThreshold"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["nameplateType"]["neutral"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["nameplateType"]["enemyNPC"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["nameplateType"]["healer"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["nameplateType"]["enable"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["nameplateType"]["enemyPlayer"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["nameplateType"]["friendlyPlayer"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["nameplateType"]["friendlyNPC"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["underHealthThreshold"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["reputation"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["friendly"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["revered"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["honored"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["hostile"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["unfriendly"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["exalted"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["neutral"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["reactionType"]["hated"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["buffs"]["minTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["buffs"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["buffs"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["buffs"]["maxTimeLeft"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["inCombat"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["healthThreshold"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["curlevel"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["isTarget"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["priority"] = 1
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["healthUsePlayer"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["classification"]["minus"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["classification"]["normal"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["classification"]["rareelite"] = true
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["classification"]["elite"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["classification"]["worldboss"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["classification"]["trivial"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["classification"]["rare"] = true
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["underPowerThreshold"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier1enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier5"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier5"]["column"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier2enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier1"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier1"]["column"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier4"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier4"]["column"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["type"] = "normal"
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier2"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier2"]["column"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier4enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier3"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier3"]["column"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier5enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier7"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier7"]["column"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier7enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["requireAll"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier6enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier3enabled"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier6"]["missing"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["talent"]["tier6"]["column"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["minlevel"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["outOfCombatUnit"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["powerUsePlayer"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["outOfCombat"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["role"]["tank"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["role"]["damager"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["role"]["healer"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["questBoss"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["overPowerThreshold"] = 0
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["cooldowns"]["mustHaveAll"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["casting"]["interruptible"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["dungeon"]["normal"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["dungeon"]["mythic+"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["dungeon"]["heroic"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["dungeon"]["timewalking"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["dungeon"]["mythic"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["normal"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["legacy25normal"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["heroic"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["legacy10normal"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["legacy10heroic"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["legacy25heroic"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["lfr"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["timewalking"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["instanceDifficulty"]["raid"]["mythic"] = false
	E.global["nameplate"]["filters"]["Rar"]["triggers"]["notTarget"] = false
	
	
	E.db["nameplates"]["clampToScreen"] = true
	E.db["nameplates"]["classbar"]["enable"] = false
	E.db["nameplates"]["filters"]["Boss"]["triggers"]["enable"] = true
	E.db["nameplates"]["filters"]["Quest"]["triggers"]["enable"] = true
	E.db["nameplates"]["filters"]["Rar"]["triggers"]["enable"] = true
	E.db["nameplates"]["font"] = "Expressway"
	E.db["nameplates"]["fontOutline"] = "NONE"
	E.db["nameplates"]["fontSize"] = 12
	E.db["nameplates"]["glowColor"]["g"] = 1
	E.db["nameplates"]["glowColor"]["r"] = 1
	E.db["nameplates"]["motionType"] = "OVERLAP"
	E.db["nameplates"]["statusbar"] = "MaUI 2"
	E.db["nameplates"]["targetGlow"] = "style1"
	E.db["nameplates"]["threat"]["badColor"]["b"] = 0.12549019607843
	E.db["nameplates"]["threat"]["badColor"]["g"] = 0.15686274509804
	E.db["nameplates"]["threat"]["badColor"]["r"] = 1
	E.db["nameplates"]["threat"]["badScale"] = 1.5
	E.db["nameplates"]["threat"]["beingTankedByTankColor"]["b"] = 0.53333333333333
	E.db["nameplates"]["threat"]["beingTankedByTankColor"]["g"] = 0.11764705882353
	E.db["nameplates"]["threat"]["beingTankedByTankColor"]["r"] = 1
	E.db["nameplates"]["threat"]["goodColor"]["b"] = 0.25490196078431
	E.db["nameplates"]["threat"]["goodColor"]["g"] = 0.89019607843137
	E.db["nameplates"]["threat"]["goodColor"]["r"] = 0.17254901960784
	E.db["nameplates"]["threat"]["goodTransition"]["b"] = 0.027450980392157
	E.db["nameplates"]["threat"]["goodTransition"]["g"] = 0.63137254901961
	E.db["nameplates"]["threat"]["goodTransition"]["r"] = 1
	E.db["nameplates"]["units"]["ENEMY_NPC"]["eliteIcon"]["enable"] = true
	E.db["nameplates"]["units"]["ENEMY_NPC"]["eliteIcon"]["xOffset"] = 10
	E.db["nameplates"]["units"]["ENEMY_NPC"]["healthbar"]["text"]["format"] = "CURRENT_PERCENT"
	E.db["nameplates"]["units"]["ENEMY_NPC"]["powerbar"]["height"] = 4
	
	--Update visible nameplates
	NP:ConfigureAll()
	
	print ("|cff1784d1Nameplates Profile installation|r |cff76FF03OK|r")
	E:UpdateAll(true)
end

local function MaUIActionbar()
	E.db["actionbar"]["backdropSpacingConverted"] = true
	E.db["actionbar"]["bar2"]["enabled"] = true
	E.db["actionbar"]["bar3"]["buttons"] = 12
	E.db["actionbar"]["bar4"]["enabled"] = false
	E.db["actionbar"]["bar5"]["buttons"] = 12
	E.db["actionbar"]["barPet"]["backdrop"] = false
	E.db["actionbar"]["barPet"]["buttonsize"] = 28
	E.db["actionbar"]["extraActionButton"]["alpha"] = 0.75
	E.db["actionbar"]["extraActionButton"]["scale"] = 0.6
	E.db["actionbar"]["font"] = "Expressway"
	E.db["actionbar"]["fontOutline"] = "OUTLINE"
	E.db["actionbar"]["fontSize"] = 12
	E.db["actionbar"]["macrotext"] = true
	
	E.db["movers"]["ElvAB_1"] = "BOTTOM,ElvUIParent,BOTTOM,0,4"
	E.db["movers"]["ElvAB_2"] = "BOTTOM,ElvUIParent,BOTTOM,0,38"
	E.db["movers"]["ElvAB_3"] = "BOTTOM,ElvUIParent,BOTTOM,312,4"
	E.db["movers"]["ElvAB_5"] = "BOTTOM,ElvUIParent,BOTTOM,-312,4"
	E.db["movers"]["BossButton"] = "BOTTOM,ElvUIParent,BOTTOM,-100,150"
	E.db["movers"]["ShiftAB"] = "TOPLEFT,ElvUIParent,BOTTOMLEFT,1171,104"
	E.db["movers"]["ZoneAbility"] = "BOTTOM,ElvUIParent,BOTTOM,100,150"
	
	print ("|cff76FF03MaUI|r ... |cff1784d1Actionbar Profile installation|r ... |cff76FF03OK|r")
	E:UpdateAll(true)
end

local function MaUIAddOns()
	--AddOnSkins
	if IsAddOnLoaded('AddOnSkins') then
		if AddOnSkinsDB["profiles"]["MaUI"] == nil then AddOnSkinsDB["profiles"]["MaUI"] = {} end
		
		AddOnSkinsDB["profiles"]["MaUI"]['DBMSkinHalf'] = false
		AddOnSkinsDB["profiles"]["MaUI"]['EmbedLeft'] = 'Skada'
		AddOnSkinsDB["profiles"]["MaUI"]['EmbedLeft'] = 'Skada'
		AddOnSkinsDB["profiles"]["MaUI"]['EmbedMain'] = 'Skada'
		AddOnSkinsDB["profiles"]["MaUI"]['EmbedRight'] = 'Skada'
		AddOnSkinsDB["profiles"]["MaUI"]['EmbedSystem'] = false
		AddOnSkinsDB["profiles"]["MaUI"]['EmbedSystemDual'] = false
		AddOnSkinsDB["profiles"]["MaUI"]['ParchmentRemover'] = true
		AddOnSkinsDB["profiles"]["MaUI"]['TransparentEmbed'] = false
		AddOnSkinsDB["profiles"]["MaUI"]['WeakAuras'] = true
		AddOnSkinsDB["profiles"]["MaUI"]['MiscellaneousFixes'] = true

		if IsAddOnLoaded('Skada') then
			AddOnSkinsDB["profiles"]["MaUI"]['EmbedBelowTop'] = false
			AddOnSkinsDB["profiles"]["MaUI"]['EmbedFrameStrata'] = "2-LOW"
			AddOnSkinsDB["profiles"]["MaUI"]['EmbedLeft'] = 'Skada'
			AddOnSkinsDB["profiles"]["MaUI"]['EmbedMain'] = 'Skada'
			AddOnSkinsDB["profiles"]["MaUI"]['EmbedRight'] = 'Skada'
			AddOnSkinsDB["profiles"]["MaUI"]['EmbedSystem'] = false
			AddOnSkinsDB["profiles"]["MaUI"]['EmbedSystemDual'] = true
			AddOnSkinsDB["profiles"]["MaUI"]['SkadaBackdrop'] = false
			AddOnSkinsDB["profiles"]["MaUI"]['TransparentEmbed'] = true
		end
		
		if IsAddOnLoaded('DBM-Core') then
			AddOnSkinsDB["profiles"]["MaUI"]['DBMFont'] = "Expressway"
			AddOnSkinsDB["profiles"]["MaUI"]['DBMFontSize'] = 12
			AddOnSkinsDB["profiles"]["MaUI"]['DBMRadarTrans'] = true
		end
		
		local db = LibStub("AceDB-3.0"):New(AddOnSkinsDB, nil, true)
		db:SetProfile("MaUI")
		
		print ("|cff76FF03MaUI|r ... |cff1784d1AddOnskins Profile installation|r ... |cff76FF03OK|r")
	end
	
	--DBM
	if IsAddOnLoaded("DBM-Core") then
		DBM:CreateProfile("Blinkii")
		
		local font = "Interface\\AddOns\\ElvUI\\media\\fonts\\Expressway.ttf"
		
		
		DBM_AllSavedOptions["Blinkii"]["SpecialWarningFontShadow"] = true
		DBM_AllSavedOptions["Blinkii"]["SpecialWarningFontStyle"] = "NONE"
		DBT_AllPersistentOptions["Blinkii"]["DBM"]["Texture"] = "Interface\\AddOns\\ElvUI_MaUI\\media\\textures\\MaUI2.tga"
		DBT_AllPersistentOptions["Blinkii"]["DBM"]["Scale"] = 1
		DBT_AllPersistentOptions["Blinkii"]["DBM"]["FontSize"] = 12
		DBT_AllPersistentOptions["Blinkii"]["DBM"]["HugeScale"] = 1
		DBT_AllPersistentOptions["Blinkii"]["DBM"]["Font"] = font
		DBM_AllSavedOptions["Blinkii"]["WarningFont"] = font
		DBM_AllSavedOptions["Blinkii"]["SpecialWarningFont"] = font
		
		DBM:ApplyProfile("Blinkii")
		print ("|cff76FF03MaUI|r ... |cff1784d1DBM Profile installation|r ... |cff76FF03OK|r")
	end
	
	--Skada
	if IsAddOnLoaded('Skada') then
		SkadaDB["profiles"]["MaUI"] = {
			["windows"] = {
				{
					["barheight"] = 15,
					["classicons"] = false,
					["barslocked"] = true,
					["wipemode"] = "Schaden erhalten",
					["y"] = 8.00005340576172,
					["x"] = 1505.00006103516,
					["title"] = {
						["color"] = {
							["a"] = 0,
							["b"] = 0.301960784313726,
							["g"] = 0.301960784313726,
							["r"] = 0.301960784313726,
						},
						["font"] = "Expressway",
						["fontsize"] = 11,
						["texture"] = "MaUI 4",
					},
					["background"] = {
						["strata"] = "LOW",
						["height"] = 95.9999923706055,
						["bordertexture"] = "None",
					},
					["point"] = "TOPRIGHT",
					["barcolor"] = {
						["b"] = 0.788235294117647,
						["g"] = 0.188235294117647,
						["r"] = 0.63921568627451,
					},
					["barfontsize"] = 12,
					["mode"] = "Schaden",
					["spark"] = false,
					["buttons"] = {
						["menu"] = false,
						["mode"] = false,
						["segment"] = false,
					},
					["barwidth"] = 196.000061035156,
					["barspacing"] = 2,
					["smoothing"] = true,
					["modeincombat"] = "Schaden",
					["bartexture"] = "MaUI 2",
					["barfont"] = "Expressway",
				}, -- [1]
				{
					["titleset"] = true,
					["barheight"] = 15,
					["classicons"] = false,
					["barslocked"] = true,
					["enabletitle"] = true,
					["wipemode"] = "Heilung erhalten",
					["set"] = "current",
					["hidden"] = false,
					["y"] = 8.00005340576172,
					["barfont"] = "Expressway",
					["name"] = "Skada 2",
					["display"] = "bar",
					["barfontflags"] = "",
					["strata"] = "LOW",
					["classcolortext"] = false,
					["scale"] = 1,
					["reversegrowth"] = false,
					["barfontsize"] = 12,
					["roleicons"] = false,
					["barorientation"] = 1,
					["snapto"] = true,
					["point"] = "TOPRIGHT",
					["mode"] = "Heilung",
					["x"] = 1705.99990844727,
					["buttons"] = {
						["segment"] = false,
						["menu"] = true,
						["mode"] = false,
						["report"] = true,
						["reset"] = true,
					},
					["spark"] = false,
					["bartexture"] = "MaUI 2",
					["barwidth"] = 201.000091552734,
					["barspacing"] = 2,
					["clickthrough"] = false,
					["smoothing"] = true,
					["barbgcolor"] = {
						["a"] = 0.6,
						["r"] = 0.3,
						["g"] = 0.3,
						["b"] = 0.3,
					},
					["barcolor"] = {
						["a"] = 1,
						["r"] = 0.63921568627451,
						["g"] = 0.188235294117647,
						["b"] = 0.788235294117647,
					},
					["background"] = {
						["strata"] = "LOW",
						["borderthickness"] = 0,
						["color"] = {
							["a"] = 0.2,
							["r"] = 0,
							["g"] = 0,
							["b"] = 0.5,
						},
						["height"] = 95.9999923706055,
						["bordertexture"] = "None",
						["margin"] = 0,
						["texture"] = "Solid",
					},
					["classcolorbars"] = true,
					["version"] = 1,
					["returnaftercombat"] = false,
					["modeincombat"] = "Heilung",
					["title"] = {
						["color"] = {
							["a"] = 0,
							["r"] = 0.101960784313725,
							["g"] = 0.101960784313725,
							["b"] = 0.101960784313725,
						},
						["bordertexture"] = "None",
						["font"] = "Expressway",
						["borderthickness"] = 2,
						["fontsize"] = 11,
						["fontflags"] = "",
						["height"] = 20,
						["margin"] = 0,
						["texture"] = "MaUI 4",
					},
				}, -- [2]
			},
			["versions"] = {
				["1.6.7"] = true,
				["1.6.4"] = true,
				["1.6.3"] = true,
			},
			["modeclicks"] = {
				["Buff-Laufzeiten"] = 1,
				["Heilung"] = 1,
				["DPS"] = 1,
				["Tode"] = 1,
				["Schaden"] = 2,
				["Unterbrechungen"] = 1,
			},
		},
		
		Skada.db:SetProfile("MaUI") -- set automatically the profile
		
		print ("|cff76FF03MaUI|r ... |cff1784d1Skada Profile installation|r ... |cff76FF03OK|r")
	end
	
	--LocPlus
	if IsAddOnLoaded('ElvUI_LocPlus') then
		DT:RegisterCustomCurrencyDT(1220)
		DT:RegisterCustomCurrencyDT(1155)
		DT:RegisterCustomCurrencyDT(1508)
		
		E.db["locplus"]["customCoordsColor"] = 2
		E.db["locplus"]["dig"] = false
		E.db["locplus"]["displayOther"] = "NONE"
		E.db["locplus"]["fish"] = false
		E.db["locplus"]["ht"] = true
		E.db["locplus"]["petlevel"] = false
		E.db["locplus"]["prof"] = false
		E.db["locplus"]["trans"] = false
		E.db["locplus"]["ttrecinst"] = false
		E.db["locplus"]["ttreczones"] = false
		E.db["locplus"]["ttst"] = false
		
		E.db["datatexts"]["panels"]["RightCoordDtPanel"] = "Uraltes Mana"
		E.db["datatexts"]["panels"]["LeftCoordDtPanel"] = "Ordensressourcen"
		E.db["movers"]["LocationMover"] = "TOP,ElvUIParent,TOP,0,-4"
		
		print ("|cff76FF03MaUI|r ... |cff1784d1LocPlus Profile installation|r ... |cff76FF03OK|r")
	end
	
	--SquareMinimapButtonBarMover
	if IsAddOnLoaded('SquareMinimapButtons') then
		E.db["movers"]["SquareMinimapButtonBarMover"] = "TOPRIGHT,ElvUIParent,TOPRIGHT,-76,-221"
		
		SquareMinimapButtonOptions = {
			["MoveBlizzard"] = false,
			["BarEnabled"] = true,
			["BarMouseOver"] = true,
			["ButtonsPerRow"] = 5,
			["ButtonSpacing"] = 2,
			["IconSize"] = 32,
		}

		print ("|cff76FF03MaUI|r ... |cff1784d1SquareMinimapButtons Profile installation|r ... |cff76FF03OK|r")
	end
	
	print ("|cff76FF03MaUI|r ... |cff1784d1AddOns Profile installation|r ... |cff76FF03OK|r")
	E:UpdateAll(true)
end

local function InstallComplete()
	E.private.install_complete = E.version
	E.db.MaUI.installed = true
	print ("|cff76FF03MaUI|r ... |cff1784d1MaUI installation|r ... |cff76FF03OK|r")
	
	ReloadUI()
end

-- ElvUI PlugIn installer
MaUI.installTable = {
	["Name"] = "|cFF6FFF10MaUI|r",
	["Title"] = L["|cFF6FFF10MaUI|r Installation"],
	["tutorialImage"] = [[Interface\AddOns\ElvUI_MaUI\media\textures\logo_MaUI.tga]],
	["Pages"] = {
		[1] = function()
			PluginInstallFrame.SubTitle:SetText(L["Welcome to |cff76FF03MaUI|r, for ElvUI."])
			PluginInstallFrame.Desc1:SetText(L["By pressing the Continue button, MaUI will be applied in your current ElvUI installation.\r|cffff8000 TIP: It would be nice if you apply the changes in a new profile, just in case you don't like the result.|r"])
			PluginInstallFrame.Desc2:SetText(L["Please press the continue button to go onto the next step."])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() InstallComplete() end)
			PluginInstallFrame.Option1:SetText(L["Skip Process"])
		end,
		[2] = function()
			PluginInstallFrame.SubTitle:SetText(L["General"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation process sets up the General Profile."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to apply the new Profile."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cff07D400High|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() MaUIGeneral() end)
			PluginInstallFrame.Option1:SetText(L["Setup General"])
		end,
		[3] = function()
			PluginInstallFrame.SubTitle:SetText(L["Unitframe"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation changes the default Unitframes look."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to apply the new layout."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cff07D400High|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() MaUIUnitframeTankDD() end)
			PluginInstallFrame.Option1:SetText(L["Setup Tank/DD"])
			PluginInstallFrame.Option2:Show()
			PluginInstallFrame.Option2:SetScript("OnClick", function() MaUIUnitframeHeal() end)
			PluginInstallFrame.Option2:SetText(L["Setup Heal"])
		end,
		[4] = function()
			PluginInstallFrame.SubTitle:SetText(L["Actionbars"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation process sets up your Actionbars."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to setup your Actionbars."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cff07D400High|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() MaUIActionbar() end)
			PluginInstallFrame.Option1:SetText(L["Setup Actionbar"])
		end,
		[5] = function()
			PluginInstallFrame.SubTitle:SetText(L["Nameplates"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation process sets up your Nameplates."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to setup your Nameplates."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffD3CF00Medium|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() MaUINameplates() end)
			PluginInstallFrame.Option1:SetText(L["Setup Nameplates"])
		end,
		[6] = function()
			PluginInstallFrame.SubTitle:SetText(L["AddOns"])
			PluginInstallFrame.Desc1:SetText(L["This part of the installation process sets up your AddOns."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below to setup your AddOns."])
			PluginInstallFrame.Desc3:SetText(L["Importance: |cffD3CF00Medium|r"])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() MaUIAddOns() end)
			PluginInstallFrame.Option1:SetText(L["Setup AddOns"])
		end,
		[7] = function()
			PluginInstallFrame.SubTitle:SetText(L["Installation Complete"])
			PluginInstallFrame.Desc1:SetText(L["You are now finished with the installation process. If you are in need of technical support please visit us at http://www.tukui.org."])
			PluginInstallFrame.Desc2:SetText(L["Please click the button below so you can setup variables and ReloadUI."])
			PluginInstallFrame.Option1:Show()
			PluginInstallFrame.Option1:SetScript("OnClick", function() InstallComplete() end)
			PluginInstallFrame.Option1:SetText(L["Finished"])
			if InstallStepComplete then
				InstallStepComplete.message = MaUI.Title..L["Installed"]
				InstallStepComplete:Show()
			end
		end,
	},
	
	["StepTitles"] = {
		[1] = START,
		[2] = L["General"],
		[3] = L["Unitframe"],
		[4] = L["Actionbar"],
		[5] = L["Nameplates"],
		[6] = L["AddOns"],
		[7] = L["Installation Complete"],
	},
	StepTitlesColorSelected = RAID_CLASS_COLORS[E.myclass],
	StepTitleWidth = 200,
	StepTitleButtonWidth = 200,
	StepTitleTextJustification = "CENTER",
}